Changelog
=========


0.2.5 (2018-03-02)
------------------
- @WIP Let's do another release. [Paul Everitt]
- @WIP The docs referenced sectionquery and we don't have a
  sectionquery.html. Remove that from the docs for now. [Paul Everitt]
- @WIP Released 0.2.4, back to dev. [Paul Everitt]


0.2.4 (2018-03-02)
------------------
- @WIP Let's make a release. [Paul Everitt]


0.2.3 (2018-03-02)
------------------

Changes
~~~~~~~
- Some widgets weren't using pathto_docname. [Paul Everitt]

Other
~~~~~
- Releasing 0.2.3. [Paul Everitt]
- @WIP Put the remaining configuration in place. [Paul Everitt]
- @WIP Let's switch to the kaybee-style packaging: not in src, using
  bumpversion and gitchangelog, similar travis.yml files, etc. [Paul
  Everitt]
- Toctree doesn't have the global pathto. [Paul Everitt]
- Let's make a PyPI release that fixes the lookup thing. [Paul Everitt]
- Wiggle wires. [Paul Everitt]
- Install requirements. [Paul Everitt]
- Need to list Sphinx as a dependency. Switch to a real requirements.txt
  file. [Paul Everitt]
- Add the information for doctr and Travis. [Paul Everitt]


0.2.0 (2018-03-02)
------------------
- Let's make a release. [Paul Everitt]
- Improve sectionbox font size. Get the layout working for featuretiles.
  [Paul Everitt]
- Is it that easy, removing the Sphinx JS? [Paul Everitt]
- Small cleanups. [Paul Everitt]
- Use SASS looping to avoid repetition. [Paul Everitt]
- No longer using a debug block. [Paul Everitt]
- Get rid of previous/next. Make a better toctree. Reorganize SCSS to be
  prefixed. Remove some duplicate nesting. [Paul Everitt]
- Make it clear this is no longer used (will delete when more
  confident.) [Paul Everitt]
- Touch up the conf file. [Paul Everitt]
- Give up on RTD and Python 3.6. [Paul Everitt]
- We have switched to latest Bulma. [Paul Everitt]
- Footer colors. [Paul Everitt]
- Get collapse working. [Paul Everitt]
- Let's start on hamburger. [Paul Everitt]
- This file is no longer used. [Paul Everitt]
- Refer to resources and references globally. [Paul Everitt]
- Get rid of old tests. [Paul Everitt]
- HTML ID and SCSS to hide the first H1 generated by Sphinx. [Paul
  Everitt]
- Put the category backlinks in. [Paul Everitt]
- Parents links. [Paul Everitt]
- Acquired styling. [Paul Everitt]
- Get SiteConfig stuff straightened out. [Paul Everitt]
- Basics are working again. [Paul Everitt]
- Make kaybee_bulma importable. [Paul Everitt]
- Time to get off branch. [Paul Everitt]
- Get things in place to produce a wheel. [Paul Everitt]
- Some dev requirements. Start the process of a decent version number.
  [Paul Everitt]
- Series are now looking better. [Paul Everitt]
- Synopsis -> excerpt. [Paul Everitt]
- Clean up toctree. [Paul Everitt]
- Start wiring in categories. [Paul Everitt]
- Sections have a model for a featured article and a helper that can go
  get that model. [Paul Everitt]
- Get rid of extra column. Hide for now the footer navigation in the
  portlet boxes. [Paul Everitt]
- Add in some credits.. [Paul Everitt]
- Not the best solution for this, but until pathto gets figured out,
  best we can do. [Paul Everitt]
- Integration test ensuring that prevnext.html works as advertised.
  [Paul Everitt]
- Get the prev/next links working. [Paul Everitt]
- Actuall get the category integration test running this time. [Paul
  Everitt]
- Move up some tests that were needlessly in own directory. Fix
  "published" test to match that it is now in an <li>. [Paul Everitt]
- PreviousNext widget with unit test. [Paul Everitt]
- Get scss working again using kaybee_bulma as target filenames. [Paul
  Everitt]
- Align the published date correctly. [Paul Everitt]
- Use the new overrides scheme. [Paul Everitt]
- Make sure the social media config knobs are present. [Paul Everitt]
- Fix other tests with the wrong siteconfig import. [Paul Everitt]
- Add a test for favicon support. [Paul Everitt]
- Fix the path for the watchers. Add a favicon path to the conf.py. Put
  <link> in <head>. [Paul Everitt]
- Make a local SiteConfig with a favicon setting. [Paul Everitt]
- Fix the integration test to match kaybee's new "all" overrides. [Paul
  Everitt]
- Need to do setup.py install into venv. [Paul Everitt]
- Wonder if RTD can handle this under 3.5. [Paul Everitt]
- See if we can configure RTD. [Paul Everitt]
- Now that kaybee is published, point to it. [Paul Everitt]
- Reflect categories change. [Paul Everitt]
- Catch up to kaybee resource/widget base refactoring. [Paul Everitt]
- No longer need any toctree-specific setup. [Paul Everitt]
- Simplify registration. [Paul Everitt]
- Add in the static stuff. [Paul Everitt]
- Refactor to match kaybee core flattening. [Paul Everitt]
- Hot dog, tests pass. [Paul Everitt]
- Unit tests pass. [Paul Everitt]
- Extracted from kaybee. [Paul Everitt]


